@@ -6,23 +6,33 @@ from __future__ import absolute_import, print_function, division
 import math
 import re
 import sys
+import inspect
 from time import time
 import datetime
 from dateutil.relativedelta import relativedelta
 from dateutil.tz import tzutc
 import calendar
 import natsort
-from future.utils import raise_from
 
 
-step_search_re = re.compile(r'^([^-]+)-([^-/]+)(/(.*))?$')
-search_re = re.compile(r'^([^-]+)-([^-/]+)(/(.*))?$')
+step_search_re = re.compile(r'^([^-]+)-([^-/]+)(/(\d+))?$')
 only_int_re = re.compile(r'^\d+$')
-any_int_re = re.compile(r'^\d+')
 star_or_int_re = re.compile(r'^(\d+|\*)$')
 VALID_LEN_EXPRESSION = [5, 6]
 
 
+def _get_caller_globals_and_locals():
+    """
+    Returns the globals and locals of the calling frame.
+
+    Is there an alternative to frame hacking here?
+    """
+    caller_frame = inspect.stack()[2]
+    myglobals = caller_frame[0].f_globals
+    mylocals = caller_frame[0].f_locals
+    return myglobals, mylocals
+
+
 class CroniterError(ValueError):
     """ General top-level Croniter base exception """
     pass
@@ -118,7 +128,7 @@ class croniter(object):
     @classmethod
     def _alphaconv(cls, index, key, expressions):
         try:
-            return cls.ALPHACONV[index][key.lower()]
+            return cls.ALPHACONV[index][key]
         except KeyError:
             raise CroniterNotAlphaError(
                 "[{0}] is not acceptable".format(" ".join(expressions)))
@@ -297,7 +307,9 @@ class croniter(object):
         DAYS = self.DAYS
 
         def proc_month(d):
-            if expanded[3][0] != '*':
+            try:
+                expanded[3].index('*')
+            except ValueError:
                 diff_month = nearest_diff_method(
                     d.month, expanded[3], self.MONTHS_IN_YEAR)
                 days = DAYS[month - 1]
@@ -319,7 +331,9 @@ class croniter(object):
             return False, d
 
         def proc_day_of_month(d):
-            if expanded[2][0] != '*':
+            try:
+                expanded[2].index('*')
+            except ValueError:
                 days = DAYS[month - 1]
                 if month == 2 and self.is_leap(year) is True:
                     days += 1
@@ -345,7 +359,9 @@ class croniter(object):
             return False, d
 
         def proc_day_of_week(d):
-            if expanded[4][0] != '*':
+            try:
+                expanded[4].index('*')
+            except ValueError:
                 diff_day_of_week = nearest_diff_method(
                     d.isoweekday() % 7, expanded[4], 7)
                 if diff_day_of_week is not None and diff_day_of_week != 0:
@@ -409,7 +425,9 @@ class croniter(object):
             return False, d
 
         def proc_hour(d):
-            if expanded[1][0] != '*':
+            try:
+                expanded[1].index('*')
+            except ValueError:
                 diff_hour = nearest_diff_method(d.hour, expanded[1], 24)
                 if diff_hour is not None and diff_hour != 0:
                     if is_prev:
@@ -421,7 +439,9 @@ class croniter(object):
             return False, d
 
         def proc_minute(d):
-            if expanded[0][0] != '*':
+            try:
+                expanded[0].index('*')
+            except ValueError:
                 diff_min = nearest_diff_method(d.minute, expanded[0], 60)
                 if diff_min is not None and diff_min != 0:
                     if is_prev:
@@ -433,7 +453,9 @@ class croniter(object):
 
         def proc_second(d):
             if len(expanded) == 6:
-                if expanded[5][0] != '*':
+                try:
+                    expanded[5].index('*')
+                except ValueError:
                     diff_sec = nearest_diff_method(d.second, expanded[5], 60)
                     if diff_sec is not None and diff_sec != 0:
                         d += relativedelta(seconds=diff_sec)
@@ -520,7 +542,10 @@ class croniter(object):
 
     @classmethod
     def _expand(cls, expr_format):
-        expressions = expr_format.split()
+        # Split the expression in components, and normalize L -> l, MON -> mon,
+        # etc. Keep expr_format untouched so we can use it in the exception
+        # messages.
+        expressions = [e.lower() for e in expr_format.split()]
 
         if len(expressions) not in VALID_LEN_EXPRESSION:
             raise CroniterBadCronError(cls.bad_length)
@@ -541,13 +566,18 @@ class croniter(object):
                         raise CroniterBadCronError(
                             "[{0}] is not acceptable".format(expr_format))
 
+                # Before matching step_search_re, normalize "*" to "{min}-{max}".
+                # Example: in the minute field, "*/5" normalizes to "0-59/5"
                 t = re.sub(r'^\*(\/.+)$', r'%d-%d\1' % (
                     cls.RANGES[i][0],
                     cls.RANGES[i][1]),
                     str(e))
-                m = search_re.search(t)
+                m = step_search_re.search(t)
 
                 if not m:
+                    # Before matching step_search_re,
+                    # normalize "{start}/{step}" to "{start}-{max}/{step}".
+                    # Example: in the minute field, "10/5" normalizes to "10-59/5"
                     t = re.sub(r'^(.+)\/(.+)$', r'\1-%d/\2' % (
                         cls.RANGES[i][1]),
                         str(e))
@@ -560,10 +590,10 @@ class croniter(object):
                     if i == 2 and high == 'l':
                         high = '31'
 
-                    if not any_int_re.search(low):
+                    if not only_int_re.search(low):
                         low = "{0}".format(cls._alphaconv(i, low, expressions))
 
-                    if not any_int_re.search(high):
+                    if not only_int_re.search(high):
                         high = "{0}".format(cls._alphaconv(i, high, expressions))
 
                     if (
@@ -641,10 +671,13 @@ class croniter(object):
             return cls._expand(expr_format)
         except ValueError as exc:
             error_type, error_instance, traceback = sys.exc_info()
-            aaa =exc
             if isinstance(exc, CroniterError):
                 raise
-            raise_from(CroniterBadCronError, exc)
+            if int(sys.version[0]) >= 3:
+                globs, locs = _get_caller_globals_and_locals()
+                exec("raise CroniterBadCronError from  exc", globs, locs)
+            else:
+                raise CroniterBadCronError("{0}".format(exc))
 
     @classmethod
     def is_valid(cls, expression):
