@@ -6,10 +6,8 @@ from datetime import datetime, timedelta
 from functools import partial
 from time import sleep
 import pytz
-import croniter as cr
 from croniter import croniter, croniter_range, CroniterBadDateError, CroniterBadCronError, CroniterNotAlphaError
 from croniter.tests import base
-from tzlocal import get_localzone
 import dateutil.tz
 
 
@@ -237,6 +235,16 @@ class CroniterTest(base.TestCase):
         self.assertEqual(n4.month, 12)
         self.assertEqual(n4.day, 31)
 
+    def testRangeWithUppercaseLastDayOfMonth(self):
+        base = datetime(2015, 9, 4)
+        itr = croniter('0 0 29-L * *', base)
+        n1 = itr.get_next(datetime)
+        self.assertEqual(n1.month, 9)
+        self.assertEqual(n1.day, 29)
+        n2 = itr.get_next(datetime)
+        self.assertEqual(n2.month, 9)
+        self.assertEqual(n2.day, 30)
+
     def testPrevLastDayOfMonth(self):
         base = datetime(2009, 12, 31, hour=20)
         itr = croniter('0 0 l * *', base)
@@ -288,6 +296,8 @@ class CroniterTest(base.TestCase):
         self.assertRaises(ValueError, croniter, '-90 * * * *')
         self.assertRaises(ValueError, croniter, 'a * * * *')
         self.assertRaises(ValueError, croniter, '* * * janu-jun *')
+        self.assertRaises(ValueError, croniter, '1-1_0 * * * *')
+        self.assertRaises(ValueError, croniter, '0-10/ * * * *')
         self.assertRaises(CroniterBadCronError, croniter, "0-1& * * * *", datetime.now())
 
     def testSundayToThursdayWithAlphaConversion(self):
@@ -1295,6 +1305,14 @@ class CroniterRangeTest(base.TestCase):
         """."""
         self.assertRaises(CroniterBadCronError, croniter , "0-10000000 * * * *", datetime.now())
 
+    def test_issue156(self):
+        """."""
+        dt = croniter("* * * * *,0", datetime(2019, 1, 14, 11, 0, 59, 999999)).get_next()
+        self.assertEqual(1547463660.0, dt)
+        self.assertRaises(CroniterBadCronError, croniter, "* * * * *,b")
+        dt = croniter("0 0 * * *,sat#3", datetime(2019, 1, 14, 11, 0, 59, 999999)).get_next()
+        self.assertEqual(1547856000.0, dt)
+
 
 if __name__ == '__main__':
     unittest.main()
